@@ -78,7 +78,7 @@ ebi('op_up2k').innerHTML = (
 	'	<tr>\n' +
 	'		<td>\n' +
 	'			<a href="#" id="nthread_sub">&ndash;</a><input\n' +
-	'				class="txtbox" id="nthread" value="2"/><a\n' +
+	'				class="txtbox" id="nthread" value="2" tt="pause uploads by setting it to 0"/><a\n' +
 	'				href="#" id="nthread_add">+</a><br />&nbsp;\n' +
 	'		</td>\n' +
 	'	</tr>\n' +
@@ -237,13 +237,17 @@ var mpl = (function () {
 		'<a href="#" class="tgl btn" tt="load the next folder and continue">📂 next-folder</a>' +
 		'</div></div>' +
 
+		'<div><h3>tint</h3><div>' +
+		'<input type="text" id="pb_tint" size="3" value="0" tt="background level (0-100) on the seekbar$Nto make buffering less distracting" />' +
+		'</div></div>' +
+
 		'<div><h3>audio equalizer</h3><div id="audio_eq"></div></div>');
 
 	var r = {
 		"pb_mode": sread('pb_mode') || 'loop-folder',
 		"preload": bcfg_get('au_preload', true),
 		"clip": bcfg_get('au_npclip', false),
-		"os_ctl": bcfg_get('au_os_ctl', false) && have_mctl,
+		"os_ctl": bcfg_get('au_os_ctl', have_mctl) && have_mctl,
 		"osd_cv": bcfg_get('au_osd_cv', true),
 	};
 
@@ -290,6 +294,26 @@ var mpl = (function () {
 		draw_pb_mode();
 	}
 
+	function set_tint() {
+		var tint = icfg_get('pb_tint', 0);
+		if (!tint)
+			ebi('barbuf').style.removeProperty('background');
+		else
+			ebi('barbuf').style.background = 'rgba(126,163,75,' + (tint / 100.0) + ')';
+	}
+	ebi('pb_tint').oninput = function (e) {
+		swrite('pb_tint', this.value);
+		set_tint();
+	};
+	set_tint();
+
+	r.pp = function () {
+		if (!r.os_ctl)
+			return;
+
+		navigator.mediaSession.playbackState = mp.au && !mp.au.paused ? "playing" : "paused";
+	};
+
 	r.announce = function () {
 		if (!r.os_ctl)
 			return;
@@ -320,18 +344,31 @@ var mpl = (function () {
 
 			if (cover) {
 				cover += (cover.indexOf('?') === -1 ? '?' : '&') + 'th=j';
+
+				var pwd = get_pwd();
+				if (pwd)
+					cover += '&pw=' + uricom_enc(pwd);
+
 				tags.artwork = [{ "src": cover, type: "image/jpeg" }];
 			}
 		}
 
 		navigator.mediaSession.metadata = new MediaMetadata(tags);
-		navigator.mediaSession.playbackState = mp.au.paused ? "paused" : "playing";
 		navigator.mediaSession.setActionHandler('play', playpause);
 		navigator.mediaSession.setActionHandler('pause', playpause);
 		navigator.mediaSession.setActionHandler('seekbackward', function () { seek_au_rel(-10); });
 		navigator.mediaSession.setActionHandler('seekforward', function () { seek_au_rel(10); });
 		navigator.mediaSession.setActionHandler('previoustrack', prev_song);
 		navigator.mediaSession.setActionHandler('nexttrack', next_song);
+		r.pp();
+	};
+
+	r.stop = function () {
+		if (!r.os_ctl || !navigator.mediaSession.metadata)
+			return;
+
+		navigator.mediaSession.metadata = null;
+		navigator.mediaSession.playbackState = "paused";
 	};
 
 	return r;
@@ -340,14 +377,15 @@ var mpl = (function () {
 
 // extract songs + add play column
 function MPlayer() {
-	this.id = Date.now();
-	this.au = null;
-	this.au_native = null;
-	this.au_native2 = null;
-	this.au_ogvjs = null;
-	this.au_ogvjs2 = null;
-	this.tracks = {};
-	this.order = [];
+	var r = this;
+	r.id = Date.now();
+	r.au = null;
+	r.au_native = null;
+	r.au_native2 = null;
+	r.au_ogvjs = null;
+	r.au_ogvjs2 = null;
+	r.tracks = {};
+	r.order = [];
 
 	var re_audio = /\.(opus|ogg|m4a|aac|mp3|wav|flac)$/i,
 		trs = QSA('#files tbody tr');
@@ -362,32 +400,33 @@ function MPlayer() {
 
 		if (m) {
 			var tid = link.getAttribute('id');
-			this.order.push(tid);
-			this.tracks[tid] = url;
+			r.order.push(tid);
+			r.tracks[tid] = url;
 			tds[0].innerHTML = '<a id="a' + tid + '" href="#a' + tid + '" class="play">play</a></td>';
 			ebi('a' + tid).onclick = ev_play;
 		}
 	}
 
-	this.vol = sread('vol');
-	if (this.vol !== null)
-		this.vol = parseFloat(this.vol);
+	r.vol = sread('vol');
+	if (r.vol !== null)
+		r.vol = parseFloat(r.vol);
 	else
-		this.vol = 0.5;
+		r.vol = 0.5;
 
-	this.expvol = function () {
-		return 0.5 * this.vol + 0.5 * this.vol * this.vol;
+	r.expvol = function (v) {
+		return 0.5 * v + 0.5 * v * v;
 	};
 
-	this.setvol = function (vol) {
-		this.vol = Math.max(Math.min(vol, 1), 0);
+	r.setvol = function (vol) {
+		r.vol = Math.max(Math.min(vol, 1), 0);
 		swrite('vol', vol);
+		r.stopfade(true);
 
-		if (this.au)
-			this.au.volume = this.expvol();
+		if (r.au)
+			r.au.volume = r.expvol(r.vol);
 	};
 
-	this.read_order = function () {
+	r.read_order = function () {
 		var order = [],
 			links = QSA('#files>tbody>tr>td:nth-child(1)>a');
 
@@ -398,24 +437,71 @@ function MPlayer() {
 
 			order.push(tid.slice(1));
 		}
-		this.order = order;
+		r.order = order;
 	};
 
-	this.preload = function (url) {
+	r.fdir = 0;
+	r.fvol = -1;
+	r.ftid = -1;
+	r.ftimer = null;
+	r.fade_in = function () {
+		r.fvol = 0;
+		r.fdir = 0.025;
+		if (r.au) {
+			r.ftid = r.au.tid;
+			r.au.play();
+			mpl.pp();
+			fader();
+		}
+	};
+	r.fade_out = function () {
+		r.fvol = r.vol;
+		r.fdir = -0.05;
+		r.ftid = r.au.tid;
+		fader();
+	};
+	r.stopfade = function (hard) {
+		clearTimeout(r.ftimer);
+		if (hard)
+			r.ftid = -1;
+	}
+	function fader() {
+		r.stopfade();
+		if (!r.au || r.au.tid !== r.ftid)
+			return;
+
+		var done = true;
+		r.fvol += r.fdir;
+		if (r.fvol < 0) {
+			r.fvol = 0;
+			r.au.pause();
+			mpl.pp();
+		}
+		else if (r.fvol > r.vol)
+			r.fvol = r.vol;
+		else
+			done = false;
+
+		r.au.volume = r.expvol(r.fvol);
+		if (!done)
+			setTimeout(fader, 10);
+	}
+
+	r.preload = function (url) {
 		var au = null;
 		if (need_ogv_for(url)) {
 			au = mp.au_ogvjs2;
 			if (!au && window['OGVPlayer']) {
 				au = new OGVPlayer();
 				au.preload = "auto";
-				this.au_ogvjs2 = au;
+				r.au_ogvjs2 = au;
 			}
 		} else {
 			au = mp.au_native2;
 			if (!au) {
 				au = new Audio();
 				au.preload = "auto";
-				this.au_native2 = au;
+				r.au_native2 = au;
 			}
 		}
 		if (au) {
@@ -453,37 +539,38 @@ function get_np() {
 
 // toggle player widget
 var widget = (function () {
-	var ret = {},
+	var r = {},
 		widget = ebi('widget'),
 		wtico = ebi('wtico'),
 		nptxt = ebi('nptxt'),
 		npirc = ebi('npirc'),
 		touchmode = false,
-		side_open = false,
 		was_paused = true;
 
-	ret.open = function () {
-		if (side_open)
+	r.is_open = false;
+
+	r.open = function () {
+		if (r.is_open)
 			return false;
 
 		widget.className = 'open';
-		side_open = true;
+		r.is_open = true;
 		return true;
 	};
-	ret.close = function () {
-		if (!side_open)
+	r.close = function () {
+		if (!r.is_open)
 			return false;
 
 		widget.className = '';
-		side_open = false;
+		r.is_open = false;
 		return true;
 	};
-	ret.toggle = function (e) {
-		ret.open() || ret.close();
+	r.toggle = function (e) {
+		r.open() || r.close();
 		ev(e);
 		return false;
 	};
-	ret.paused = function (paused) {
+	r.paused = function (paused) {
 		if (was_paused != paused) {
 			was_paused = paused;
 			ebi('bplay').innerHTML = paused ? '▶' : '⏸';
@@ -491,7 +578,7 @@ var widget = (function () {
 	};
 	wtico.onclick = function (e) {
 		if (!touchmode)
-			ret.toggle(e);
+			r.toggle(e);
 
 		return false;
 	};
@@ -522,7 +609,7 @@ var widget = (function () {
 			document.body.removeChild(o);
 		}, 500);
 	};
-	return ret;
+	return r;
 })();
 
 
@@ -568,12 +655,15 @@ var pbar = (function () {
 	}
 
 	r.drawbuf = function () {
+		var bc = r.buf,
+			bctx = bc.ctx;
+
+		bctx.clearRect(0, 0, bc.w, bc.h);
+
 		if (!mp.au)
 			return;
 
-		var bc = r.buf,
-			bctx = bc.ctx,
-			sm = bc.w * 1.0 / mp.au.duration,
+		var sm = bc.w * 1.0 / mp.au.duration,
 			gk = bc.h + '' + light;
 
 		if (gradh != gk) {
@@ -581,7 +671,6 @@ var pbar = (function () {
 			grad = glossy_grad(bc, 85, [35, 40, 37, 35], light ? [45, 56, 50, 45] : [42, 51, 47, 42]);
 		}
 		bctx.fillStyle = grad;
-		bctx.clearRect(0, 0, bc.w, bc.h);
 		for (var a = 0; a < mp.au.buffered.length; a++) {
 			var x1 = sm * mp.au.buffered.start(a),
 				x2 = sm * mp.au.buffered.end(a);
@@ -591,15 +680,17 @@ var pbar = (function () {
 	};
 
 	r.drawpos = function () {
+		var bc = r.buf,
+			pc = r.pos,
+			pctx = pc.ctx;
+
+		pctx.clearRect(0, 0, pc.w, pc.h);
+
 		if (!mp.au || isNaN(mp.au.duration) || isNaN(mp.au.currentTime))
 			return;  // not-init || unsupp-codec
 
-		var bc = r.buf,
-			pc = r.pos,
-			pctx = pc.ctx,
-			sm = bc.w * 1.0 / mp.au.duration;
+		var sm = bc.w * 1.0 / mp.au.duration;
 
-		pctx.clearRect(0, 0, pc.w, pc.h);
 		pctx.fillStyle = light ? 'rgba(0,64,0,0.15)' : 'rgba(204,255,128,0.15)';
 		for (var p = 1, mins = mp.au.duration / 10; p <= mins; p++)
 			pctx.fillRect(Math.floor(sm * p * 10), 0, 2, pc.h);
@@ -730,9 +821,8 @@ function seek_au_sec(seek) {
 
 	mp.au.currentTime = seek;
 
-	// ogv.js breaks on .play() during playback
-	if (mp.au === mp.au_native)
-		mp.au.play();
+	if (mp.au.paused)
+		mp.fade_in();
 
 	mpui.progress_updater();
 }
@@ -754,25 +844,29 @@ function next_song(e) {
 }
 function prev_song(e) {
 	ev(e);
+
+	if (mp.au && !mp.au.paused && mp.au.currentTime > 3)
+		return seek_au_sec(0);
+
 	return song_skip(-1);
 }
 
 
 function playpause(e) {
+	// must be event-chain
 	ev(e);
 	if (mp.au) {
 		if (mp.au.paused)
-			mp.au.play();
+			mp.fade_in();
 		else
-			mp.au.pause();
+			mp.fade_out();
 
 		mpui.progress_updater();
 	}
 	else
-		play(0);
+		play(0, true);
 
-	if (navigator.mediaSession)
-		navigator.mediaSession.playbackState = mp.au.paused ? "paused" : "playing";
+	mpl.pp();
 };
 
 
@@ -781,9 +875,13 @@ function playpause(e) {
 	ebi('bplay').onclick = playpause;
 	ebi('bprev').onclick = prev_song;
 	ebi('bnext').onclick = next_song;
-	ebi('barpos').onclick = function (e) {
+
+	var bar = ebi('barpos');
+
+	bar.onclick = function (e) {
 		if (!mp.au) {
-			return play(0);
+			play(0, true);
+			return mp.fade_in();
 		}
 
 		var rect = pbar.buf.can.getBoundingClientRect(),
@@ -791,6 +889,19 @@ function playpause(e) {
 
 		seek_au_mul(x * 1.0 / rect.width);
 	};
+
+	if (!is_touch)
+		bar.onwheel = function (e) {
+			var dist = Math.sign(e.deltaY) * 10;
+			if (Math.abs(e.deltaY) < 30 && !e.deltaMode)
+				dist = e.deltaY;
+
+			if (!dist || !mp.au)
+				return true;
+
+			seek_au_rel(dist);
+			ev(e);
+		};
 })();
 
 
@@ -858,7 +969,12 @@ var mpui = (function () {
 // event from play button next to a file in the list
 function ev_play(e) {
 	ev(e);
-	play(this.getAttribute('id').slice(1));
+
+	var fade = !mp.au || mp.au.paused;
+	play(this.getAttribute('id').slice(1), true);
+	if (fade)
+		mp.fade_in();
+
 	return false;
 }
 
@@ -1097,13 +1213,18 @@ var audio_eq = (function () {
 
 
 // plays the tid'th audio file on the page
-function play(tid, seek, call_depth) {
+function play(tid, is_ev, seek, call_depth) {
 	if (mp.order.length == 0)
 		return console.log('no audio found wait what');
 
+	mp.stopfade(true);
+
 	var tn = tid;
-	if ((tn + '').indexOf('f-') === 0)
+	if ((tn + '').indexOf('f-') === 0) {
 		tn = mp.order.indexOf(tn);
+		if (tn < 0)
+			return;
+	}
 
 	if (tn >= mp.order.length) {
 		if (mpl.pb_mode == 'loop-folder') {
@@ -1142,7 +1263,7 @@ function play(tid, seek, call_depth) {
 		}
 		else if (window['OGVPlayer']) {
 			mp.au = mp.au_ogvjs = new OGVPlayer();
-			attempt_play = false;
+			attempt_play = is_ev;
 			mp.au.addEventListener('error', evau_error, true);
 			mp.au.addEventListener('progress', pbar.drawpos);
 			mp.au.addEventListener('ended', next_song);
@@ -1155,7 +1276,7 @@ function play(tid, seek, call_depth) {
 			show_modal('<h1>loading ogv.js</h1><h2>thanks apple</h2>');
 
 			import_js('/.cpr/deps/ogv.js', function () {
-				play(tid, seek, 1);
+				play(tid, false, seek, 1);
 			});
 
 			return;
@@ -1176,7 +1297,7 @@ function play(tid, seek, call_depth) {
 
 	mp.au.tid = tid;
 	mp.au.src = url + (url.indexOf('?') < 0 ? '?cache' : '&cache');
-	mp.au.volume = mp.expvol();
+	mp.au.volume = mp.expvol(mp.vol);
 	var oid = 'a' + tid;
 	setclass(oid, 'play act');
 	var trs = ebi('files').getElementsByTagName('tbody')[0].getElementsByTagName('tr');
@@ -1267,7 +1388,8 @@ function show_modal(html) {
 
 
 // hide fullscreen message
-function unblocked() {
+function unblocked(e) {
+	ev(e);
 	var dom = ebi('blocked');
 	if (dom)
 		dom.parentNode.removeChild(dom);
@@ -1282,28 +1404,25 @@ function autoplay_blocked(seek) {
 
 	var go = ebi('blk_go'),
 		na = ebi('blk_na'),
-		fn = mp.tracks[mp.au.tid].split(/\//).pop();
+		tid = mp.au.tid,
+		fn = mp.tracks[tid].split(/\//).pop();
 
 	fn = uricom_dec(fn.replace(/\+/g, ' '))[0];
 
 	go.textContent = 'Play "' + fn + '"';
 	go.onclick = function (e) {
-		if (e) e.preventDefault();
-		unblocked();
-		mp.au.play();
-		if (seek)
-			seek_au_sec(seek);
-		else
-			mpui.progress_updater();
-
-		mpl.announce();
+		unblocked(e);
+		// chrome 91 may permanently taint on a failed play()
+		// depending on win10 settings or something? idk
+		mp.au_native = mp.au_ogvjs = null;
+		play(tid, true, seek);
+		mp.fade_in();
 	};
 	na.onclick = unblocked;
 }
 
 
-// autoplay linked track
-(function () {
+function play_linked() {
 	var v = location.hash;
 	if (v && v.indexOf('#af-') === 0) {
 		var id = v.slice(2).split('&');
@@ -1317,9 +1436,9 @@ function autoplay_blocked(seek) {
 		if (!m)
 			return play(id[0]);
 
-		return play(id[0], parseInt(m[1] || 0) * 60 + parseInt(m[2] || 0));
+		return play(id[0], false, parseInt(m[1] || 0) * 60 + parseInt(m[2] || 0));
 	}
-})();
+};
 
 
 var thegrid = (function () {
@@ -1425,35 +1544,57 @@ var thegrid = (function () {
 	}
 	setsz();
 
-	function seltgl(e) {
-		if (e && e.ctrlKey)
+	function gclick(e) {
+		if (e && (e.ctrlKey || e.metaKey))
 			return true;
 
-		ev(e);
 		var oth = ebi(this.getAttribute('ref')),
-			td = oth.parentNode.nextSibling,
+			href = this.getAttribute('href'),
+			aplay = ebi('a' + oth.getAttribute('id')),
+			is_img = /\.(gif|jpe?g|png|webp)(\?|$)/i.test(href),
+			in_tree = null,
+			have_sel = QS('#files tr.sel'),
+			td = oth.closest('td').nextSibling,
 			tr = td.parentNode;
 
-		td.click();
-		this.setAttribute('class', tr.getAttribute('class'));
-	}
+		if (/\/(\?|$)/.test(href)) {
+			var ta = QSA('#treeul a.hl+ul>li>a+a'),
+				txt = oth.textContent.slice(0, -1);
 
-	function bgopen(e) {
+			for (var a = 0, aa = ta.length; a < aa; a++) {
+				if (ta[a].textContent == txt) {
+					in_tree = ta[a];
+					break;
+				}
+			}
+		}
+
+		if (r.sel) {
+			td.click();
+			this.setAttribute('class', tr.getAttribute('class'));
+		}
+		else if (widget.is_open && aplay)
+			aplay.click();
+
+		else if (in_tree && !have_sel)
+			in_tree.click();
+
+		else if (!is_img && have_sel)
+			window.open(href, '_blank');
+
+		else return true;
 		ev(e);
-		var url = this.getAttribute('href');
-		window.open(url, '_blank');
 	}
 
 	r.loadsel = function () {
 		if (r.dirty)
 			return;
 
-		var ths = QSA('#ggrid>a'),
-			have_sel = !!QS('#files tr.sel');
+		var ths = QSA('#ggrid>a');
 
 		for (var a = 0, aa = ths.length; a < aa; a++) {
-			ths[a].onclick = r.sel ? seltgl : have_sel ? bgopen : null;
-			ths[a].setAttribute('class', ebi(ths[a].getAttribute('ref')).parentNode.parentNode.getAttribute('class'));
+			var tr = ebi(ths[a].getAttribute('ref')).closest('tr');
+			ths[a].setAttribute('class', tr.getAttribute('class'));
 		}
 		var uns = QS('#ggrid a[ref="unsearch"]');
 		if (uns)
@@ -1484,6 +1625,8 @@ var thegrid = (function () {
 
 			if (r.thumbs) {
 				ihref += (ihref.indexOf('?') === -1 ? '?' : '&') + 'th=' + (have_webp ? 'w' : 'j');
+				if (href == "#")
+					ihref = '/.cpr/ico/⏏️';
 			}
 			else if (isdir) {
 				ihref = '/.cpr/ico/folder';
@@ -1511,6 +1654,11 @@ var thegrid = (function () {
 				ihref + '" /><span' + ac + '>' + ao.innerHTML + '</span></a>');
 		}
 		ebi('ggrid').innerHTML = html.join('\n');
+
+		var ths = QSA('#ggrid>a');
+		for (var a = 0, aa = ths.length; a < aa; a++)
+			ths[a].onclick = gclick;
+
 		r.dirty = false;
 		r.bagit();
 		r.loadsel();
@@ -1598,19 +1746,25 @@ document.onkeydown = function (e) {
 	if (!document.activeElement || document.activeElement != document.body && document.activeElement.nodeName.toLowerCase() != 'a')
 		return;
 
-	if (e.ctrlKey || e.altKey || e.shiftKey || e.metaKey || e.isComposing)
+	if (e.ctrlKey || e.altKey || e.metaKey || e.isComposing)
+		return;
+
+	var k = (e.code + ''), pos = -1, n;
+
+	if (e.shiftKey && k != 'KeyA' && k != 'KeyD')
 		return;
 
-	var k = (e.code + ''), pos = -1;
 	if (k.indexOf('Digit') === 0)
 		pos = parseInt(k.slice(-1)) * 0.1;
 
 	if (pos !== -1)
 		return seek_au_mul(pos) || true;
 
-	var n = k == 'KeyJ' ? -1 : k == 'KeyL' ? 1 : 0;
-	if (n !== 0)
-		return song_skip(n) || true;
+	if (k == 'KeyJ')
+		return prev_song() || true;
+
+	if (k == 'KeyL')
+		return next_song() || true;
 
 	if (k == 'KeyP')
 		return playpause() || true;
@@ -1635,6 +1789,14 @@ document.onkeydown = function (e) {
 	if (k == 'KeyT')
 		return ebi('thumbs').click();
 
+	if (!treectl.hidden && (!e.shiftKey || !thegrid.en)) {
+		if (k == 'KeyA')
+			return QS('#twig').click();
+
+		if (k == 'KeyD')
+			return QS('#twobytwo').click();
+	}
+
 	if (thegrid.en) {
 		if (k == 'KeyS')
 			return ebi('gridsel').click();
@@ -1717,6 +1879,7 @@ document.onkeydown = function (e) {
 	}
 
 	var search_timeout,
+		defer_timeout,
 		search_in_progress = 0;
 
 	function ev_search_input() {
@@ -1731,9 +1894,29 @@ document.onkeydown = function (e) {
 		if (id != "q_raw")
 			encode_query();
 
-		clearTimeout(search_timeout);
-		if (Date.now() - search_in_progress > 30 * 1000)
+		set_vq();
+
+		clearTimeout(defer_timeout);
+		defer_timeout = setTimeout(try_search, 2000);
+		try_search();
+	}
+
+	function try_search() {
+		if (Date.now() - search_in_progress > 30 * 1000) {
+			clearTimeout(defer_timeout);
+			clearTimeout(search_timeout);
 			search_timeout = setTimeout(do_search, 200);
+		}
+	}
+
+	function set_vq() {
+		if (search_in_progress)
+			return;
+
+		var q = ebi('q_raw').value,
+			vq = ebi('files').getAttribute('q_raw');
+
+		srch_msg(false, (q == vq) ? '' : 'search results below are from a previous query:\n  ' + (vq ? vq : '(*)'));
 	}
 
 	function encode_query() {
@@ -1803,7 +1986,8 @@ document.onkeydown = function (e) {
 		xhr.setRequestHeader('Content-Type', 'text/plain');
 		xhr.onreadystatechange = xhr_search_results;
 		xhr.ts = Date.now();
-		xhr.send(JSON.stringify({ "q": ebi('q_raw').value }));
+		xhr.q_raw = ebi('q_raw').value;
+		xhr.send(JSON.stringify({ "q": xhr.q_raw }));
 	}
 
 	function xhr_search_results() {
@@ -1874,6 +2058,8 @@ document.onkeydown = function (e) {
 
 		ofiles.innerHTML = html.join('\n');
 		ofiles.setAttribute("ts", this.ts);
+		ofiles.setAttribute("q_raw", this.q_raw);
+		set_vq();
 		mukey.render();
 		reload_browser();
 		filecols.set_style(['File Name']);
@@ -1885,6 +2071,7 @@ document.onkeydown = function (e) {
 		ev(e);
 		treectl.show();
 		ebi('files').innerHTML = orig_html;
+		ebi('files').removeAttribute('q_raw');
 		orig_html = null;
 		msel.render();
 		reload_browser();
@@ -2103,6 +2290,9 @@ var treectl = (function () {
 	}
 
 	function treego(e) {
+		if (e && (e.ctrlKey || e.metaKey))
+			return true;
+
 		ev(e);
 		if (this.getAttribute('class') == 'hl' &&
 			this.previousSibling.textContent == '-') {
@@ -2833,8 +3023,10 @@ function reload_mp() {
 		mp.au.pause();
 		mp.au = null;
 	}
+	mpl.stop();
 	widget.close();
 	mp = new MPlayer();
+	setTimeout(pbar.onresize, 1);
 }
 
 
@@ -2878,3 +3070,4 @@ function reload_browser(not_mp) {
 reload_browser(true);
 mukey.render();
 msel.render();
+play_linked();
