@@ -1,7 +1,5 @@
 "use strict";
 
-window.onerror = vis_exh;
-
 
 function goto_up2k() {
     if (up2k === false)
@@ -740,9 +738,17 @@ function up2k_init(subtle) {
 
     function handshakes_permitted() {
         var lim = multitask ? 1 : 0;
-        return lim >=
+
+        if (lim <
             st.todo.upload.length +
-            st.busy.upload.length;
+            st.busy.upload.length)
+            return false;
+
+        var cd = st.todo.handshake.length ? st.todo.handshake[0].cooldown : 0;
+        if (cd && cd - Date.now() > 0)
+            return false;
+
+        return true;
     }
 
     function hashing_permitted() {
@@ -1155,6 +1161,15 @@ function up2k_init(subtle) {
                 if (rsp.indexOf('<pre>') === 0)
                     rsp = rsp.slice(5);
 
+                if (rsp.indexOf('rate-limit ') !== -1) {
+                    var penalty = rsp.replace(/.*rate-limit /, "").split(' ')[0];
+                    console.log("rate-limit: " + penalty);
+                    t.cooldown = Date.now() + parseFloat(penalty) * 1000;
+                    st.busy.handshake.splice(st.busy.handshake.indexOf(t), 1);
+                    st.todo.handshake.unshift(t);
+                    return;
+                }
+
                 st.bytes.uploaded += t.size;
                 if (rsp.indexOf('partial upload exists') !== -1 ||
                     rsp.indexOf('file already exists') !== -1) {
@@ -1292,6 +1307,17 @@ function up2k_init(subtle) {
     }
     tt.init();
 
+    function bumpthread2(e) {
+        if (e.ctrlKey || e.altKey || e.metaKey || e.isComposing)
+            return;
+
+        if (e.code == 'ArrowUp')
+            bumpthread(1);
+
+        if (e.code == 'ArrowDown')
+            bumpthread(-1);
+    }
+
     function bumpthread(dir) {
         try {
             dir.stopPropagation();
@@ -1302,7 +1328,7 @@ function up2k_init(subtle) {
         if (dir.target) {
             clmod(obj, 'err', 1);
             var v = Math.floor(parseInt(obj.value));
-            if (v < 1 || v > 8 || v !== v)
+            if (v < 0 || v > 64 || v !== v)
                 return;
 
             parallel_uploads = v;
@@ -1313,11 +1339,11 @@ function up2k_init(subtle) {
 
         parallel_uploads += dir;
 
-        if (parallel_uploads < 1)
-            parallel_uploads = 1;
+        if (parallel_uploads < 0)
+            parallel_uploads = 0;
 
-        if (parallel_uploads > 8)
-            parallel_uploads = 8;
+        if (parallel_uploads > 16)
+            parallel_uploads = 16;
 
         obj.value = parallel_uploads;
         bumpthread({ "target": 1 })
@@ -1413,6 +1439,7 @@ function up2k_init(subtle) {
         bumpthread(-1);
     };
 
+    ebi('nthread').onkeydown = bumpthread2;
     ebi('nthread').addEventListener('input', bumpthread, false);
     ebi('multitask').addEventListener('click', tgl_multitask, false);
     ebi('ask_up').addEventListener('click', tgl_ask_up, false);
@@ -1426,7 +1453,10 @@ function up2k_init(subtle) {
         nodes[a].addEventListener('touchend', nop, false);
 
     set_fsearch();
-    bumpthread({ "target": 1 })
+    bumpthread({ "target": 1 });
+    if (parallel_uploads < 1)
+        bumpthread(1);
+
     return { "init_deps": init_deps, "set_fsearch": set_fsearch }
 }
 
